@@ -39,10 +39,29 @@
 //!   engine.exec();
 //! }
 //! ```
+use qmetaobject::prelude::*;
 use std::ffi::c_void;
 
+#[cfg(not(no_qt))]
 use cpp::{cpp, cpp_class};
-use qmetaobject::prelude::*;
+
+#[cfg(no_qt)]
+mod no_qt {
+    pub fn panic<T>() -> T {
+        panic!("This example is not supported on Qt 6 and above")
+    }
+}
+
+#[cfg(no_qt)]
+macro_rules! cpp {
+    {{ $($t:tt)* }} => {};
+    {$(unsafe)? [$($a:tt)*] -> $ret:ty as $b:tt { $($t:tt)* } } => {
+        crate::no_qt::panic::<$ret>()
+    };
+    { $($t:tt)* } => {
+        crate::no_qt::panic::<()>()
+    };
+}
 
 cpp! {{
     #include <KLocalizedContext>
@@ -96,4 +115,43 @@ impl KLocalizedContext {
             return self->klocalized.get();
         })
     }
+
+    /// Set Translation Domain for current KLocalizedContext.
+    /// ```rust
+    /// use qmetaobject::prelude::*;
+    /// use ki18n_rs::KLocalizedContext;
+    ///
+    /// let mut engine = QmlEngine::new();
+    /// let mut context = KLocalizedContext::init_from_engine(&engine);
+    ///
+    /// const TRANSLATION_DOMAIN: &str = "Test Domain";
+    /// context.set_translation_domain(TRANSLATION_DOMAIN.into());
+    ///
+    /// let domain = context.translation_domain();
+    ///
+    /// assert_eq!(domain, QString::from(TRANSLATION_DOMAIN));
+    /// ```
+    pub fn set_translation_domain(&mut self, domain: QString) {
+        cpp!(unsafe [self as "KLocalizedContextHolder *", domain as "QString"] {
+            self->klocalized->setTranslationDomain(domain);
+        })
+    }
+
+    /// Retrns the current Translation Domain.
+    /// ```rust
+    /// use qmetaobject::prelude::*;
+    /// use ki18n_rs::KLocalizedContext;
+    ///
+    /// let mut engine = QmlEngine::new();
+    /// let mut context = KLocalizedContext::init_from_engine(&engine);
+    ///
+    /// let domain = context.translation_domain();
+    ///
+    /// assert_eq!(domain, QString::from(""));
+    /// ```
+    pub fn translation_domain(&self) -> QString {
+        cpp!(unsafe [self as "KLocalizedContextHolder *"] -> QString as "QString" {
+            return self->klocalized->translationDomain();
+        })
+    }
 }
